% Batch file for the PCA analysis of the case study 2 relating analysis
% of NMR spectra of edible oils.
% the data are collected for 1100 variables that are the wavelength of
% the NMR spectrum
% The data are collected for 28 different samples that are:
%   - 5 samples from canola oil
%   - 5 samples from corn oil
%   - 5 samples from olive oil
%   - 5 samples from sesame oil
%   - 3 samples from sunflower oil
% Eventually the matrix is saved in the variable "totspectra" that is a
% (1100x28) matrix. Pay attention since the variables are along the
% columns. 
% This is a particular case where the number of variables is much larger
% than the number of samples
%% Load spectra
load data_NMROils
%% PCA algorithm with the function PCA
[coeff,score,latent]=pca(totspectra');
% N.B. the variables should be arranged columnwise. This implies that
% matrix totspectra has to be transposed
% In addition, unity variance scaling was not carried out
% In general it is not suggested when spectral data are processed. 
% A possible alternative to the unity variance scaling is the Pareto
% scaling:
%               xtr=(x-mean(x))./sqrt(std(x))
% This is strongly recommended for NMR data
%% Graphical representation of the first two scores 
plot(score(1:5,1),score(1:5,2),'ro',score(6:10,1),score(6:10,2),'bo',...
    score(11:15,1),score(11:15,2),'ko',score(16:20,1),score(16:20,2),'mo',...
    score(21:25,1),score(21:25,2),'go',score(26:end,1),score(26:end,2),'rs',...
    'Linewidth',2.0,'Markersize',10);
%% Outlier removal 
% A point is suspected to be an outlier. We can detect it by searching the
% only points having the second score that is smaller than -5
d=find(score(:,2)<-5);
totspectrarem=totspectra;
totspectrarem(:,d)=[];
% with the previous instruction, the 5th column of the matrix is
% substituted with an empty matrix (i.e. it is removed)
% the sample to be removed is the 5th one (belonging to the canola oils)
%% Repeating the PCA algorithm after the outlier removal
[coeffrem,scorerem,latentrem]=pca(totspectrarem');
%% Graphical representation of the first two scores after outlier removal
figure
plot(scorerem(1:4,1),scorerem(1:4,2),'ro',scorerem(5:9,1),scorerem(5:9,2),'bo',...
    scorerem(10:14,1),scorerem(10:14,2),'ko',scorerem(15:19,1),scorerem(15:19,2),'mo',...
    scorerem(20:24,1),scorerem(20:24,2),'go',scorerem(25:end,1),scorerem(25:end,2),'rs',...
    'Linewidth',2.0,'Markersize',10);
legend(label)
%% projection of the new points onto the PCA space
% the first step requires the translation of the new data onto the center
% evaluated with the previous ones
unknowncentered = unknown-mean(totspectrarem,2);
scoreunknown=unknowncentered'*coeffrem;
hold on
plot(scoreunknown(:,1),scoreunknown(:,2),'r*','Linewidth',2.0,'Markersize',10);
% representation of the first two scores of the new data projected onto the 
% PCA model
% It is clear from the graphical representation that the unknown spectra
% are likely to belong to the corn oils